@@ -82,7 +82,6 @@ warning(const char *fmt, ...)
 #endif
 {
 	struct timeval tv;
-	static char lbuf[512];
 	va_list ap;
 #ifdef USE_VARARGS
 	const char *fmt;
@@ -91,11 +90,10 @@ warning(const char *fmt, ...)
 #else
 	va_start(ap, fmt);
 #endif
-	vsprintf(lbuf, fmt, ap);
-	va_end(ap);
 	gettimeofday(&tv, NULL);
 	fprintf(stderr, "%02d:%02d:%02d.%06lu ", HH(tv.tv_sec), MM(tv.tv_sec), SS(tv.tv_sec), tv.tv_usec);
-	fputs(lbuf, stderr);
+	vfprintf(stderr, fmt, ap);
+	va_end(ap);
 	return 0;
 }/* warning */
 
@@ -121,7 +119,6 @@ va_dcl
 error(const char *fmt, ...)
 #endif
 {
-	static char lbuf[512];
 	va_list ap;
 #ifdef USE_VARARGS
 	const char *fmt;
@@ -130,10 +127,11 @@ error(const char *fmt, ...)
 #else
 	va_start(ap, fmt);
 #endif
-	strcat(strncpyz(lbuf, myname, sizeof(lbuf) - 3), ": ");
-	vsprintf(strchr(lbuf, '\0'), fmt, ap);
+	fprintf(stderr, "%s: ", myname);
+	vfprintf(stderr, fmt, ap);
+	fprintf(stderr, ": ");
+	perror(NULL);
 	va_end(ap);
-	perror(lbuf);
 	return 0;
 }/* error */
 
