@@ -437,10 +437,9 @@ static char *
 cryption(char *str, int decode_flag)
 {
 	unsigned char *p = (unsigned char *)str;
-	int xx = decode_flag ? 0x100 - '\n' : '\n';
 	while (*p != '\0') {
-		if (*p != '\n' && *p != 0x100 - '\n')
-			*p = (*p + xx) & 0xff;
+		if (*p != '\n' && *p != 0xff - '\n')
+			*p ^= 0xff;
 		p++;
 	}/* while */
 	return str;
@@ -691,6 +690,7 @@ send_dialog(Widget parent, const struct maddr_t *dstaddr, const char *to)
 {
 	struct from_t *fr = from_lookup(to);
 	String label = XtMalloc(strlen(to) + 1);
+	struct maddr_t *daddr = (void *)XtMalloc(sizeof(*daddr));
 	Widget send_popup = XtVaCreatePopupShell("send_popup", transientShellWidgetClass, toplevel, NULL);
 	Widget send_to = XtVaCreateManagedWidget("send_to", dialogWidgetClass, send_popup,
 		XtNlabel, (strcpy(label, to)),
@@ -701,7 +701,9 @@ send_dialog(Widget parent, const struct maddr_t *dstaddr, const char *to)
 		XtNfromHoriz, NULL,
 		NULL);
 	Position nx, ny;
+	*daddr = *dstaddr;
 	XtAddCallback(send_to, XtNdestroyCallback, destroy_proc, label);
+	XtAddCallback(send_to, XtNdestroyCallback, destroy_proc, daddr);
 	make_menu("icon_menu", "icon", icon_button, NULL, NUMBER_OF_MENU, icon_select);
 	if (last_msg[0] == '\0') {
 		Widget entry = XtNameToWidget(icon_button, "*icon00");
@@ -710,7 +712,7 @@ send_dialog(Widget parent, const struct maddr_t *dstaddr, const char *to)
 	XtVaSetValues(icon_button, XtNbitmap, last_icon, NULL);
 	XawDialogAddButton(send_to, "clear", clear_proc, NULL);
 	XawDialogAddButton(send_to, "cancel", done_proc, NULL);
-	XawDialogAddButton(send_to, "send", send_proc, (XtPointer)dstaddr);
+	XawDialogAddButton(send_to, "send", send_proc, (XtPointer)daddr);
 	XtTranslateCoords(parent, 0, 0, &nx, &ny);
 	XtVaSetValues(send_popup, XtNx, nx, XtNy, ny, NULL);
 	XtPopup(send_popup, XtGrabNone);
@@ -1270,6 +1272,7 @@ main(int argc, char *argv[])
 		bros = cvs_list(app_resources.broadcast);
 		strncpyz(entity_name, name, sizeof(entity_name));
 		gethostname(hostname, sizeof(hostname));
+		hostname[sizeof(hostname) - 1] = '\0';
 		if (strchr(hostname, '.') != NULL)
 			*strchr(hostname, '.') = '\0';
 		bro_so = bro_init(port, entity_name, hostname, (void *)bros);
